package X3D::FieldTypes::MFImage;

our $VERSION = '0.009';

use X3D::Package 'MFImage : X3DArrayField { [] }';

1;
__END__
